@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 # 标准库导入
 import datetime
+import os
+from pathlib import Path
 import platform
 from typing import Any, Callable, Dict, List, Optional, Protocol, Tuple, Union
 
@@ -13,15 +15,17 @@ from yaspin import yaspin  # type: ignore
 from jarvis.jarvis_platform.base import BasePlatform
 from jarvis.jarvis_platform.registry import PlatformRegistry
 # jarvis_utils 相关
-from jarvis.jarvis_utils.config import (get_max_token_count,
+from jarvis.jarvis_utils.config import (get_data_dir, get_max_token_count,
                                         get_max_tool_call_count,
                                         is_auto_complete,
                                         is_execute_tool_confirm,
-                                        is_use_analysis, is_use_methodology)
+                                        is_use_analysis, get_history_count, is_use_methodology)
 from jarvis.jarvis_utils.embedding import get_context_token_count
-from jarvis.jarvis_utils.globals import (delete_agent, get_interrupt, make_agent_name,
-                                         set_agent, set_interrupt)
+from jarvis.jarvis_utils.globals import (delete_agent, get_interrupt,
+                                         make_agent_name, set_agent,
+                                         set_interrupt)
 from jarvis.jarvis_utils.input import get_multiline_input
+from jarvis.jarvis_utils.jarvis_history import JarvisHistory
 from jarvis.jarvis_utils.methodology import (load_methodology,
                                              upload_methodology)
 from jarvis.jarvis_utils.output import OutputType, PrettyOutput
@@ -112,28 +116,16 @@ origin_agent_system_prompt = f"""
 
 
 class OutputHandlerProtocol(Protocol):
-    def name(self) -> str:
-        ...
+    def name(self) -> str: ...
 
-    def can_handle(self, response: str) -> bool:
-        ...
+    def can_handle(self, response: str) -> bool: ...
 
-    def prompt(self) -> str:
-        ...
+    def prompt(self) -> str: ...
 
-    def handle(self, response: str, agent: Any) -> Tuple[bool, Any]:
-        ...
+    def handle(self, response: str, agent: Any) -> Tuple[bool, Any]: ...
 
 
 class Agent:
-    def set_summary_prompt(self, summary_prompt: str):
-        """设置任务完成时的总结提示模板。
-
-        参数:
-            summary_prompt: 用于生成任务总结的提示模板
-        """
-        self.summary_prompt = summary_prompt
-
     def clear(self):
         """清除当前对话历史，保留系统消息。
 
@@ -147,6 +139,7 @@ class Agent:
         self.prompt = ""
 
     def __del__(self):
+        self.history.stop_record()
         delete_agent(self.name)
 
     def __init__(
@@ -167,6 +160,7 @@ class Agent:
         use_methodology: Optional[bool] = None,
         use_analysis: Optional[bool] = None,
         files: List[str] = [],
+        history_count: Optional[int] = None,
     ):
         self.files = files
         """初始化Jarvis Agent实例
@@ -195,7 +189,9 @@ class Agent:
             if isinstance(platform, str):
                 self.model = PlatformRegistry().create_platform(platform)
                 if self.model is None:
-                    PrettyOutput.print(f"平台 {platform} 不存在，将使用普通模型", OutputType.WARNING)
+                    PrettyOutput.print(
+                        f"平台 {platform} 不存在，将使用普通模型", OutputType.WARNING
+                    )
                     self.model = PlatformRegistry().get_normal_platform()
             else:
                 self.model = platform
@@ -243,6 +239,13 @@ class Agent:
         self.max_tool_call_count = get_max_tool_call_count()
         self.after_tool_call_cb: Optional[Callable[[Agent], None]] = None
 
+        self.history = JarvisHistory()
+        self.history_dir = str(Path(get_data_dir())/"history")
+        self.history.start_record(self.history_dir)
+
+        self.history_count = history_count if history_count is not None else get_history_count()
+
+
         self.execute_tool_confirm = (
             execute_tool_confirm
             if execute_tool_confirm is not None
@@ -395,6 +398,8 @@ class Agent:
         if self.addon_prompt:
             message += f"\n\n{self.addon_prompt}"
             self.addon_prompt = ""
+        else:
+            message += f"\n\n{self.make_default_addon_prompt(need_complete)}"
 
         # 累加对话长度
         self.conversation_length += get_context_token_count(message)
@@ -402,8 +407,10 @@ class Agent:
         if self.conversation_length > self.max_token_count:
             message = self._summarize_and_clear_history() + "\n\n" + message
             self.conversation_length += get_context_token_count(message)
+        self.history.append_msg("user", message)
         response = self.model.chat_until_success(message)  # type: ignore
         self.conversation_length += get_context_token_count(response)
+        self.history.append_msg("assistant", response)
         return response
 
     def generate_summary(self) -> str:
@@ -466,13 +473,25 @@ class Agent:
         注意:
             当上下文长度超过最大值时使用
         """
-        summary = self.generate_summary()
-        self.clear_history()  # type: ignore
+        need_summary = True
+        tmp_file_name = ""
+        try:
+            if self.model and self.model.support_upload_files():
+                need_summary = False
+            if need_summary:
+                summary = self.generate_summary()
+            else:
+                import tempfile
+                tmp_file = tempfile.NamedTemporaryFile(delete=False)
+                tmp_file_name = tmp_file.name
+                self.history.save_history(tmp_file_name)
+            self.clear_history()  # type: ignore
 
-        if not summary:
-            return ""
+            if need_summary:
+                if not summary:
+                    return ""
 
-        return f"""
+                return f"""
 以下是之前对话的关键信息总结：
 
 <content>
@@ -480,7 +499,15 @@ class Agent:
 </content>
 
 请基于以上信息继续完成任务。请注意，这是之前对话的摘要，上下文长度已超过限制而被重置。请直接继续任务，无需重复已完成的步骤。如有需要，可以询问用户以获取更多信息。
-"""
+        """
+            else:
+                if self.model and self.model.upload_files([tmp_file_name]):
+                    return "上传的文件是历史对话信息，请基于历史对话信息继续完成任务。"
+                else:
+                    return ""
+        finally:
+            if tmp_file_name:
+                os.remove(tmp_file_name)
 
     def _call_tools(self, response: str) -> Tuple[bool, Any]:
         """调用工具执行响应
@@ -526,7 +553,9 @@ class Agent:
         if not self.execute_tool_confirm or user_confirm(
             f"需要执行{tool_list[0].name()}确认执行？", True
         ):
-            with yaspin(text=f"正在执行{tool_list[0].name()}...", color="cyan") as spinner:
+            with yaspin(
+                text=f"正在执行{tool_list[0].name()}...", color="cyan"
+            ) as spinner:
                 with spinner.hidden():
                     result = tool_list[0].handle(response, self)
                 spinner.text = f"{tool_list[0].name()}执行完成"
@@ -724,6 +753,40 @@ arguments:
                 spinner.text = "分析失败"
                 spinner.fail("❌")
 
+    def make_default_addon_prompt(self, need_complete: bool) -> str:
+        """生成附加提示。
+
+        参数:
+            need_complete: 是否需要完成任务
+
+        """
+        # 结构化系统指令
+        action_handlers = ", ".join([handler.name() for handler in self.output_handler])
+
+        # 任务完成提示
+        complete_prompt = (
+            f"- 输出{ot('!!!COMPLETE!!!')}"
+            if need_complete and self.auto_complete
+            else ""
+        )
+
+        addon_prompt = f"""
+<system_prompt>
+    请判断是否已经完成任务，如果已经完成：
+    - 直接输出完成原因，不需要再有新的操作，不要输出{ot("TOOL_CALL")}标签
+    {complete_prompt}
+    如果没有完成，请进行下一步操作：
+    - 仅包含一个操作
+    - 如果信息不明确，请请求用户补充
+    - 如果执行过程中连续失败5次，请使用ask_user询问用户操作
+    - 操作列表：{action_handlers}
+</system_prompt>
+
+请继续。
+"""
+
+        return addon_prompt
+
     def run(self, user_input: str) -> Any:
         """处理用户输入并执行任务
 
@@ -745,29 +808,27 @@ arguments:
             set_agent(self.name, self)
 
             while True:
+                history_md = ""
                 if self.first:
-                    # 如果有上传文件，先上传文件
-                    if (
-                        self.files
-                        and self.model
-                        and self.model.support_upload_files()
-                    ):
-                        self.model.upload_files(self.files)
-
-                    # 如果启用方法论且没有上传文件，上传方法论
-                    elif self.use_methodology:
-                        if not self.model or not upload_methodology(self.model):
-                            # 上传失败则回退到本地加载
-                            msg = self.prompt
-                            for handler in self.input_handler:
-                                msg, _ = handler(msg, self)
-                            self.prompt = f"{self.prompt}\n\n以下是历史类似问题的执行经验，可参考：\n{load_methodology(msg, self.get_tool_registry())}"
-
-                    self.first = False
+                    history_md = self._first_run()
                 try:
                     current_response = self._call_model(self.prompt, True)
                     self.prompt = ""
 
+                    if get_interrupt():
+                        set_interrupt(False)
+                        user_input = self.multiline_inputer(
+                            f"模型交互期间被中断，请输入用户干预信息："
+                        )
+                        if user_input:
+                            # 如果有工具调用且用户确认继续，则将干预信息和工具执行结果拼接为prompt
+                            if any(handler.can_handle(current_response) for handler in self.output_handler):
+                                if user_confirm("检测到有工具调用，是否继续处理工具调用？", True):
+                                    self.prompt = f"{user_input}\n\n{current_response}"
+                                    continue
+                            self.prompt += f"{user_input}"
+                            continue
+
                     need_return, self.prompt = self._call_tools(current_response)
 
                     if need_return:
@@ -776,14 +837,6 @@ arguments:
                     if self.after_tool_call_cb:
                         self.after_tool_call_cb(self)
 
-                    if get_interrupt():
-                        set_interrupt(False)
-                        user_input = self.multiline_inputer(
-                            f"模型交互期间被中断，请输入用户干预信息："
-                        )
-                        if user_input:
-                            self.prompt += f"\n\n用户干预信息：{user_input}"
-
                     if self.prompt or self.addon_prompt:
                         continue
 
@@ -805,6 +858,8 @@ arguments:
                         return self._complete_task()
 
                 except Exception as e:
+                    if history_md:
+                        os.remove(history_md)
                     PrettyOutput.print(f"任务失败: {str(e)}", OutputType.ERROR)
                     return f"Task failed: {str(e)}"
 
@@ -812,6 +867,48 @@ arguments:
             PrettyOutput.print(f"任务失败: {str(e)}", OutputType.ERROR)
             return f"Task failed: {str(e)}"
 
+    def _first_run(self):
+        history_md = ""
+        if self.history_count > 0 and self.model and self.model.support_upload_files():
+            import tempfile
+            timestamp = datetime.datetime.now().strftime("%Y%m%d_%H%M%S")
+            history_md = str(Path(tempfile.gettempdir())/f"{self.name}_history_{timestamp}.md")
+            self.history.export_history_to_markdown(self.history_dir, history_md, max_files=self.history_count)
+            self.files.append(history_md)
+
+                        # 如果有上传文件，先上传文件
+        if self.model and self.model.support_upload_files():
+            if self.use_methodology:
+                if not upload_methodology(self.model, other_files=self.files):
+                    if self.files:
+                        PrettyOutput.print("文件上传失败，将忽略文件列表", OutputType.WARNING)
+                                    # 上传失败则回退到本地加载
+                    msg = self.prompt
+                    for handler in self.input_handler:
+                        msg, _ = handler(msg, self)
+                    self.prompt = f"{self.prompt}\n\n以下是历史类似问题的执行经验，可参考：\n{load_methodology(msg, self.get_tool_registry())}"
+                else:
+                    if self.files:
+                        self.prompt = f"{self.prompt}\n\n上传的文件包含历史对话信息和方法论文件，可以从中获取一些经验信息。"
+                    else:
+                        self.prompt = f"{self.prompt}\n\n上传的文件包含历史对话信息，可以从中获取一些经验信息。"
+            elif self.files:
+                if not self.model.upload_files(self.files):
+                    PrettyOutput.print("文件上传失败，将忽略文件列表", OutputType.WARNING)
+                else:
+                    self.prompt = f"{self.prompt}\n\n上传的文件包含历史对话信息，可以从中获取一些经验信息。"
+        else:
+            if self.files:
+                PrettyOutput.print("不支持上传文件，将忽略文件列表", OutputType.WARNING)
+            if self.use_methodology:
+                msg = self.prompt
+                for handler in self.input_handler:
+                    msg, _ = handler(msg, self)
+                self.prompt = f"{self.prompt}\n\n以下是历史类似问题的执行经验，可参考：\n{load_methodology(msg, self.get_tool_registry())}"
+
+        self.first = False
+        return history_md
+
     def clear_history(self):
         """清空对话历史但保留系统提示
 
