@@ -374,7 +374,6 @@ def role_command(args):
 
 def service_command(args):
     """Process service subcommand - start OpenAI-compatible API server"""
-    import json
     import os
     import time
     import uuid
@@ -784,7 +783,10 @@ def main():
     # role subcommand
     role_parser = subparsers.add_parser("role", help="加载角色配置文件并开始对话")
     role_parser.add_argument(
-        "--config", "-c", default="~/.jarvis/roles.yaml", help="角色配置文件路径(YAML格式，默认: ~/.jarvis/roles.yaml)"
+        "--config",
+        "-c",
+        default="~/.jarvis/roles.yaml",
+        help="角色配置文件路径(YAML格式，默认: ~/.jarvis/roles.yaml)",
     )
 
     args = parser.parse_args()
