@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-import os
 from typing import Any, Dict
 
 from jarvis.jarvis_platform.registry import PlatformRegistry
@@ -10,18 +9,16 @@ class SearchWebTool:
     description = "搜索互联网上的信息"
     parameters = {
         "type": "object",
-        "properties": {
-            "query": {"type": "string", "description": "具体的问题"}
-        }
+        "properties": {"query": {"type": "string", "description": "具体的问题"}},
     }
 
-    def execute(self, args: Dict[str, Any]) -> Dict[str, Any]: # type: ignore
+    def execute(self, args: Dict[str, Any]) -> Dict[str, Any]:  # type: ignore
         query = args.get("query")
         model = PlatformRegistry().get_normal_platform()
         model.set_web(True)
-        model.set_suppress_output(False) # type: ignore
+        model.set_suppress_output(False)  # type: ignore
         return {
-            "stdout": model.chat_until_success(query), # type: ignore
+            "stdout": model.chat_until_success(query),  # type: ignore
             "stderr": "",
             "success": True,
         }
@@ -29,4 +26,4 @@ class SearchWebTool:
     @staticmethod
     def check() -> bool:
         """检查当前平台是否支持web功能"""
-        return PlatformRegistry().get_normal_platform().support_web()
\ No newline at end of file
+        return PlatformRegistry().get_normal_platform().support_web()
